@@ -1,10 +1,10 @@
 package File::Find::Object;
-$File::Find::Object::VERSION = '0.3.5';
+$File::Find::Object::VERSION = '0.3.6';
 use strict;
 use warnings;
 
 package File::Find::Object::DeepPath;
-$File::Find::Object::DeepPath::VERSION = '0.3.5';
+$File::Find::Object::DeepPath::VERSION = '0.3.6';
 use strict;
 use warnings;
 
@@ -67,7 +67,7 @@ sub _move_next
 }
 
 package File::Find::Object::TopPath;
-$File::Find::Object::TopPath::VERSION = '0.3.5';
+$File::Find::Object::TopPath::VERSION = '0.3.6';
 use parent 'File::Find::Object::PathComp';
 
 sub new
@@ -658,7 +658,7 @@ File::Find::Object - An object oriented File::Find replacement
 
 =head1 VERSION
 
-version 0.3.5
+version 0.3.6
 
 =head1 SYNOPSIS
 
@@ -825,14 +825,6 @@ L<https://metacpan.org/release/File-Find-Object>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/File-Find-Object>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -841,14 +833,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Find-Object>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/File-Find-Object>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
