@@ -1,5 +1,5 @@
 package File::Find::Object::Base;
-$File::Find::Object::Base::VERSION = '0.3.5';
+$File::Find::Object::Base::VERSION = '0.3.6';
 use strict;
 use warnings;
 
@@ -60,7 +60,7 @@ File::Find::Object::Base - base class for File::Find::Object
 
 =head1 VERSION
 
-version 0.3.5
+version 0.3.6
 
 =head1 DESCRIPTION
 
@@ -109,14 +109,6 @@ L<https://metacpan.org/release/File-Find-Object>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/File-Find-Object>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -125,14 +117,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Find-Object>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/File-Find-Object>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
